# NSoT

![Network Source of Truth](https://raw.githubusercontent.com/dropbox/nsot/master/docs/_static/logo_128.png)

[![CI](https://github.com/jathanism/nsot/actions/workflows/ci.yml/badge.svg)](https://github.com/jathanism/nsot/actions/workflows/ci.yml)
[![Documentation Status](https://readthedocs.org/projects/nsot/badge/?version=latest&style=flat)](https://readthedocs.org/projects/nsot/?badge=latest)
[![PyPI Status](https://img.shields.io/pypi/v/nsot.svg?style=flat)](https://pypi.python.org/pypi/nsot)

Network Source of Truth (NSoT) is a source of truth database and repository for
tracking inventory and metadata of network entities to ease management and
automation of network infrastructure.

NSoT is an API-first application that provides a REST API and a web application
front-end for managing IP addresses (IPAM), network devices, and network
interfaces.

## Resources

- [Documentation](http://nsot.readthedocs.io/)
- [Python API client/CLI utility](http://pynsot.readthedocs.io/)
